==> kara-uc-1.1.66.tgz: package/src/frame/frame.js <==
import React, {Component} from 'react'
import {Redirect, Route, Router, Switch} from 'react-router-dom'
import createBrowserHistory from 'history/createBrowserHistory'
import './layout.css'
import KaraUC from '../kara-uc/index'
import httpAgent from './httpAgent'
import {Forward, Modal, Scroll} from 'karaui'
import 'karaui/lib/index.css'

export default class Frame extends Component{

  constructor(props) {
    super(props)
    this.state = {
      clientType: 'web',
      mainHeight: '100%',
      mainTop: '0',
    }
  }

  history = createBrowserHistory({
    basename: `/`
  })

  componentDidMount() {

    const {clientType} = this.state
    const frame = document.getElementById('app')
    frame.className = clientType
    if (clientType === 'web') {
      this.resize({target: window})
      window.addEventListener('resize', this.resize, false)
    }
  }

  resize = (e) => {
    const target = e.target
    const height = target.innerHeight
    const frame = document.getElementById('app')
    if (height >= 900) {
      frame.style.height = '900px'
      frame.style.marginTop = `${(height - 900) / 2}px`
    } else {
      frame.style.height = '100%'
      frame.style.marginTop = '0'
    }
  }


  render(){
    const karaChatConfigs = {
      language: 'zh',
      token: sessionStorage.token || 'ngKNWrNoxLDyvqoiOdKo3r1e12Rgxn3W',
      apiRoot: 'https://xin-sandbox.asiainfo.com:16020/api', // https://karagw.asiainfo.com/api
      apiVersion: 'v1.0.0',
      apiForward: 'https://xin-sandbox.asiainfo.com:14503/mobileapps/kara-quan-mobileweb/topic',
      httpAgent: httpAgent('ngKNWrNoxLDyvqoiOdKo3r1e12Rgxn3W','https://xin-sandbox.asiainfo.com:16020/api','v1.0.0'),
      karaui:{Forward, Modal, Scroll},
      user: {"accountId":"U3KM96QD6","accountName":"马子萌","accountStatus":"10","accountType":"Employee","address":"北京","autoIcon":"1","bgId":"30802","childAccountCount":0,"companyId":"101","companyName":"亚信中国","costCenter":"17309","costCenterName":"CIT TD","email":"mazm@asiainfo.com","gender":"M","headIcon":"https://xinbuluo.101test.com/personheadicon/U3KM96QD6_180131165707.png","mobile":"15311415404","nickName":"奥特蛋","officeAddr":"北京","org":"CIT TD WEB-BJ","orgName":"CIT TD WEB-BJ","parentAccountId":"UZBVDKC4J","parentStaffId":"231076","parentStaffName":"张春林","personId":"217414","regionId":"01","regionName":"北京","sbu":"亚信软件CIT","sbuId":"165","signature":"远离杠精，珍爱生命","staffAccount":"mazm","staffCode":"33559","staffId":"217414","staffName":"马子萌","staffType":"Employee","username":"mazm","welStatus":false},
      match: {params: {type: '1'}}
    }
    return (
      <Router history={this.history}>
        <div className="kf-body">
        <Switch>
          <Route path="/uc" component={(props)=><KaraUC {...props} config={karaChatConfigs}  />} />
          <Redirect to="/uc" />
        </Switch>
        </div>
      </Router>
    )
  }
}

==> kara-uc-1.1.93.tgz: package/src/frame/frame.js <==
import React, {Component} from 'react'
import {Redirect, Route, Router, Switch} from 'react-router-dom'
import createBrowserHistory from 'history/createBrowserHistory'
import './layout.css'
import KaraUC from '../kara-uc/index'
import httpAgent from './httpAgent'
import {Forward, Modal, Scroll} from 'karaui'
import 'karaui/lib/index.css'

export default class Frame extends Component{

  constructor(props) {
    super(props)
    this.state = {
      clientType: 'web',
      mainHeight: '100%',
      mainTop: '0',
    }
  }

  history = createBrowserHistory({
    basename: `/`
  })

  componentDidMount() {

    const {clientType} = this.state
    const frame = document.getElementById('app')
    frame.className = clientType
    if (clientType === 'web') {
      this.resize({target: window})
      window.addEventListener('resize', this.resize, false)
    }
  }

  resize = (e) => {
    const target = e.target
    const height = target.innerHeight
    const frame = document.getElementById('app')
    if (height >= 900) {
      frame.style.height = '900px'
      frame.style.marginTop = `${(height - 900) / 2}px`
    } else {
      frame.style.height = '100%'
      frame.style.marginTop = '0'
    }
  }


  render(){
    const karaChatConfigs = {
      language: 'zh',
      token: sessionStorage.token,
      apiRoot: 'https://xin-sandbox.asiainfo.com:16020/api', // https://karagw.asiainfo.com/api
      apiVersion: 'v1.0.0',
      apiForward: 'https://xin-sandbox.asiainfo.com:14503/mobileapps/kara-quan-mobileweb/topic',
      httpAgent: httpAgent('https://xin-sandbox.asiainfo.com:16020/api','v1.0.0'),
      karaui:{Forward, Modal, Scroll},
      user: {"accountId":"U3KM96QD6","accountName":"马子萌","accountStatus":"10","accountType":"Employee","address":"北京","autoIcon":"1","bgId":"30802","childAccountCount":0,"companyId":"101","companyName":"亚信中国","costCenter":"17309","costCenterName":"CIT TD","email":"mazm@asiainfo.com","gender":"M","headIcon":"https://xinbuluo.101test.com/personheadicon/U3KM96QD6_180131165707.png","mobile":"15311415404","nickName":"奥特蛋","officeAddr":"北京","org":"CIT TD WEB-BJ","orgName":"CIT TD WEB-BJ","parentAccountId":"UZBVDKC4J","parentStaffId":"231076","parentStaffName":"张春林","personId":"217414","regionId":"01","regionName":"北京","sbu":"亚信软件CIT","sbuId":"165","signature":"远离杠精，珍爱生命","staffAccount":"mazm","staffCode":"33559","staffId":"217414","staffName":"马子萌","staffType":"Employee","username":"mazm","welStatus":false},
      match: {params: {type: '1'}}
    }
    return (
      <Router history={this.history}>
        <div className="kf-body">
        <Switch>
          <Route path="/uc" component={(props)=><KaraUC {...props} config={karaChatConfigs}  />} />
          <Redirect to="/uc" />
        </Switch>
        </div>
      </Router>
    )
  }
}
